# My Word Segmenter

A Python module to segment concatenated words into valid words using dynamic programming.

## Installation

```bash
pip install dylanswordsegmenter

```

## Usage

```bash
python3 dylanswordsegmenter/example.py

```

## Run Test
```bash
pytest dylanswordsegmenter/tests/

```
